@@ -3,16 +3,15 @@ Ensemble Model Base Class
 """
 
 from abc import abstractmethod
-
-from typing import List, Optional, Union, Sequence
 from functools import reduce
+from typing import List, Optional, Sequence, Union
 
-from darts.timeseries import TimeSeries
-from darts.logging import get_logger, raise_if_not, raise_if
+from darts.logging import get_logger, raise_if, raise_if_not
 from darts.models.forecasting.forecasting_model import (
     ForecastingModel,
     GlobalForecastingModel,
 )
+from darts.timeseries import TimeSeries
 
 logger = get_logger(__name__)
 
@@ -69,7 +68,7 @@ class EnsembleModel(GlobalForecastingModel):
         series: Union[TimeSeries, Sequence[TimeSeries]],
         past_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
         future_covariates: Optional[Union[TimeSeries, Sequence[TimeSeries]]] = None,
-    ) -> None:
+    ):
         """
         Fits the model on the provided series.
         Note that `EnsembleModel.fit()` does NOT call `fit()` on each of its constituent forecasting models.
@@ -105,6 +104,8 @@ class EnsembleModel(GlobalForecastingModel):
 
         super().fit(series, past_covariates, future_covariates)
 
+        return self
+
     def _stack_ts_seq(self, predictions):
         # stacks list of predictions into one multivariate timeseries
         return reduce(lambda a, b: a.stack(b), predictions)
