@@ -291,6 +291,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         past_covariates: Optional[TimeSeries] = None,
         future_covariates: Optional[TimeSeries] = None,
         num_samples: int = 1,
+        train_length: Optional[int] = None,
         start: Union[pd.Timestamp, float, int] = 0.5,
         forecast_horizon: int = 1,
         stride: int = 1,
@@ -329,6 +330,11 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         num_samples
             Number of times a prediction is sampled from a probabilistic model. Should be left set to 1
             for deterministic models.
+        train_length
+            Number of time steps in our training set (size of backtesting window to train on).
+            Default is set to train_length=None where it takes all available time steps up until prediction time,
+            otherwise the moving window strategy is used. If larger than the number of time steps available, all steps
+            up until prediction time are used, as in default case. Needs to be at least min_train_series_length.
         start
             The first point of time at which a prediction is computed for a future time.
             This parameter supports 3 different data types: ``float``, ``int`` and ``pandas.Timestamp``.
@@ -377,6 +383,24 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
             logger,
         )
 
+        if train_length and not isinstance(train_length, int):
+            raise_log(
+                TypeError("If not None, train_length needs to be an integer."),
+                logger,
+            )
+        elif (train_length is not None) and train_length < 1:
+            raise_log(
+                ValueError("If not None, train_length needs to be positive."),
+                logger,
+            )
+        elif (train_length is not None) and train_length < self.min_train_series_length:
+            raise_log(
+                ValueError(
+                    "train_length is too small for the training requirements of this model"
+                ),
+                logger,
+            )
+
         # prepare the start parameter -> pd.Timestamp
         start = series.get_timestamp_at_point(start)
 
@@ -404,7 +428,10 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
 
         # iterate and forecast
         for pred_time in iterator:
-            train = series.drop_after(pred_time)  # build the training series
+            # build the training series
+            train = series.drop_after(pred_time)
+            if train_length and len(train) > train_length:
+                train = train[-train_length:]
 
             # train_cov = covariates.drop_after(pred_time) if covariates else None
 
@@ -453,6 +480,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         past_covariates: Optional[TimeSeries] = None,
         future_covariates: Optional[TimeSeries] = None,
         num_samples: int = 1,
+        train_length: Optional[int] = None,
         start: Union[pd.Timestamp, float, int] = 0.5,
         forecast_horizon: int = 1,
         stride: int = 1,
@@ -495,6 +523,11 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         num_samples
             Number of times a prediction is sampled from a probabilistic model. Should be left set to 1
             for deterministic models.
+        train_length
+            Number of time steps in our training set (size of backtesting window to train on).
+            Default is set to train_length=None where it takes all available time steps up until prediction time,
+            otherwise the moving window strategy is used. If larger than the number of time steps available, all steps
+            up until prediction time are used, as in default case. Needs to be at least min_train_series_length.
         start
             The first prediction time, at which a prediction is computed for a future time.
             This parameter supports 3 different types: ``float``, ``int`` and ``pandas.Timestamp``.
@@ -533,6 +566,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
             past_covariates=past_covariates,
             future_covariates=future_covariates,
             num_samples=num_samples,
+            train_length=train_length,
             start=start,
             forecast_horizon=forecast_horizon,
             stride=stride,
@@ -569,7 +603,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
         verbose=False,
         n_jobs: int = 1,
         n_random_samples: Optional[Union[int, float]] = None,
-    ) -> Tuple["ForecastingModel", Dict]:
+    ) -> Tuple["ForecastingModel", Dict[str, Any], float]:
         """
         Find the best hyper-parameters among a given set using a grid search.
 
@@ -660,9 +694,10 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
 
         Returns
         -------
-        ForecastingModel, Dict
+        ForecastingModel, Dict, float
             A tuple containing an untrained `model_class` instance created from the best-performing hyper-parameters,
-            along with a dictionary containing these best hyper-parameters.
+            along with a dictionary containing these best hyper-parameters,
+            and metric score for the best hyper-parameters.
         """
         raise_if_not(
             (forecast_horizon is not None)
@@ -707,7 +742,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
             zip(params_cross_product), verbose, total=len(params_cross_product)
         )
 
-        def _evaluate_combination(param_combination):
+        def _evaluate_combination(param_combination) -> float:
             param_combination_dict = dict(
                 list(zip(parameters.keys(), param_combination))
             )
@@ -748,9 +783,11 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
                 )
                 error = metric(pred, val_series)
 
-            return error
+            return float(error)
 
-        errors = _parallel_apply(iterator, _evaluate_combination, n_jobs, {}, {})
+        errors: List[float] = _parallel_apply(
+            iterator, _evaluate_combination, n_jobs, {}, {}
+        )
 
         min_error = min(errors)
 
@@ -760,7 +797,7 @@ class ForecastingModel(ABC, metaclass=ModelMeta):
 
         logger.info("Chosen parameters: " + str(best_param_combination))
 
-        return model_class(**best_param_combination), best_param_combination
+        return model_class(**best_param_combination), best_param_combination, min_error
 
     def residuals(
         self, series: TimeSeries, forecast_horizon: int = 1, verbose: bool = False
@@ -1135,8 +1172,13 @@ class DualCovariatesForecastingModel(ForecastingModel, ABC):
                 future_covariates.end_time() >= start, invalid_time_span_error, logger
             )
 
+            offset = (
+                n - 1
+                if isinstance(future_covariates.time_index, pd.DatetimeIndex)
+                else n
+            )
             future_covariates = future_covariates[
-                start : start + (n - 1) * self.training_series.freq
+                start : start + offset * self.training_series.freq
             ]
 
             raise_if_not(
