@@ -8,16 +8,19 @@ from typing import Any, Dict, Optional, Sequence, Tuple
 import pytorch_lightning as pl
 import torch
 import torch.nn as nn
-from joblib import delayed, Parallel
+from joblib import Parallel, delayed
 
 from darts.logging import get_logger, raise_if, raise_log
 from darts.timeseries import TimeSeries
 from darts.utils.likelihood_models import Likelihood
 from darts.utils.timeseries_generation import _build_forecast_series
 
-
 logger = get_logger(__name__)
 
+# Check whether we are running pytorch-lightning >= 1.6.0 or not:
+tokens = pl.__version__.split(".")
+pl_160_or_above = int(tokens[0]) >= 1 and int(tokens[1]) >= 6
+
 
 class PLForecastingModule(pl.LightningModule, ABC):
     @abstractmethod
@@ -56,18 +59,19 @@ class PLForecastingModule(pl.LightningModule, ABC):
             This parameter will be ignored for probabilistic models if the ``likelihood`` parameter is specified.
             Default: ``torch.nn.MSELoss()``.
         likelihood
-            The likelihood model to be used for probabilistic forecasts.
+            One of Darts' :meth:`Likelihood <darts.utils.likelihood_models.Likelihood>` models to be used for
+            probabilistic forecasts. Default: ``None``.
         optimizer_cls
-            The PyTorch optimizer class to be used (default: ``torch.optim.Adam``).
+            The PyTorch optimizer class to be used. Default: ``torch.optim.Adam``.
         optimizer_kwargs
             Optionally, some keyword arguments for the PyTorch optimizer (e.g., ``{'lr': 1e-3}``
             for specifying a learning rate). Otherwise the default values of the selected ``optimizer_cls``
-            will be used.
+            will be used. Default: ``None``.
         lr_scheduler_cls
             Optionally, the PyTorch learning rate scheduler class to be used. Specifying ``None`` corresponds
-            to using a constant learning rate.
+            to using a constant learning rate. Default: ``None``.
         lr_scheduler_kwargs
-            Optionally, some keyword arguments for the PyTorch learning rate scheduler.
+            Optionally, some keyword arguments for the PyTorch learning rate scheduler. Default: ``None``.
         """
         super().__init__()
 
@@ -118,7 +122,7 @@ class PLForecastingModule(pl.LightningModule, ABC):
             -1
         ]  # By convention target is always the last element returned by datasets
         loss = self._compute_loss(output, target)
-        self.log("train_loss", loss, batch_size=train_batch[0].shape[0])
+        self.log("train_loss", loss, batch_size=train_batch[0].shape[0], prog_bar=True)
         return loss
 
     def validation_step(self, val_batch, batch_idx) -> torch.Tensor:
@@ -126,7 +130,7 @@ class PLForecastingModule(pl.LightningModule, ABC):
         output = self._produce_train_output(val_batch[:-1])
         target = val_batch[-1]
         loss = self._compute_loss(output, target)
-        self.log("val_loss", loss, batch_size=val_batch[0].shape[0])
+        self.log("val_loss", loss, batch_size=val_batch[0].shape[0], prog_bar=True)
         return loss
 
     def predict_step(
@@ -324,10 +328,12 @@ class PLForecastingModule(pl.LightningModule, ABC):
 
     @property
     def epochs_trained(self):
-        # trained epochs are only 0 when global step and current epoch are 0, else current epoch + 1
         current_epoch = self.current_epoch
-        if self.current_epoch or self.global_step:
+
+        # For PTL < 1.6.0 we have to adjust:
+        if not pl_160_or_above and (self.current_epoch or self.global_step):
             current_epoch += 1
+
         return current_epoch
 
 
